Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ClusterServiceBrokerExpansion
- type ClusterServiceBrokerInterface
- type ClusterServiceBrokersGetter
- type ClusterServiceClassExpansion
- type ClusterServiceClassInterface
- type ClusterServiceClassesGetter
- type ClusterServicePlanExpansion
- type ClusterServicePlanInterface
- type ClusterServicePlansGetter
- type ServiceBindingExpansion
- type ServiceBindingInterface
- type ServiceBindingsGetter
- type ServiceBrokerExpansion
- type ServiceBrokerInterface
- type ServiceBrokersGetter
- type ServiceClassExpansion
- type ServiceClassInterface
- type ServiceClassesGetter
- type ServiceInstanceExpansion
- type ServiceInstanceInterface
- type ServiceInstancesGetter
- type ServicePlanExpansion
- type ServicePlanInterface
- type ServicePlansGetter
- type ServicecatalogClient
- func (c *ServicecatalogClient) ClusterServiceBrokers() ClusterServiceBrokerInterface
- func (c *ServicecatalogClient) ClusterServiceClasses() ClusterServiceClassInterface
- func (c *ServicecatalogClient) ClusterServicePlans() ClusterServicePlanInterface
- func (c *ServicecatalogClient) RESTClient() rest.Interface
- func (c *ServicecatalogClient) ServiceBindings(namespace string) ServiceBindingInterface
- func (c *ServicecatalogClient) ServiceBrokers(namespace string) ServiceBrokerInterface
- func (c *ServicecatalogClient) ServiceClasses(namespace string) ServiceClassInterface
- func (c *ServicecatalogClient) ServiceInstances(namespace string) ServiceInstanceInterface
- func (c *ServicecatalogClient) ServicePlans(namespace string) ServicePlanInterface
- type ServicecatalogInterface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterServiceBrokerExpansion ¶ added in v0.0.24
type ClusterServiceBrokerExpansion interface{}
type ClusterServiceBrokerInterface ¶ added in v0.0.24
type ClusterServiceBrokerInterface interface {
Create(*servicecatalog.ClusterServiceBroker) (*servicecatalog.ClusterServiceBroker, error)
Update(*servicecatalog.ClusterServiceBroker) (*servicecatalog.ClusterServiceBroker, error)
UpdateStatus(*servicecatalog.ClusterServiceBroker) (*servicecatalog.ClusterServiceBroker, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ClusterServiceBroker, error)
List(opts v1.ListOptions) (*servicecatalog.ClusterServiceBrokerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ClusterServiceBroker, err error)
ClusterServiceBrokerExpansion
}
ClusterServiceBrokerInterface has methods to work with ClusterServiceBroker resources.
type ClusterServiceBrokersGetter ¶ added in v0.0.24
type ClusterServiceBrokersGetter interface {
ClusterServiceBrokers() ClusterServiceBrokerInterface
}
ClusterServiceBrokersGetter has a method to return a ClusterServiceBrokerInterface. A group's client should implement this interface.
type ClusterServiceClassExpansion ¶ added in v0.0.24
type ClusterServiceClassExpansion interface{}
type ClusterServiceClassInterface ¶ added in v0.0.24
type ClusterServiceClassInterface interface {
Create(*servicecatalog.ClusterServiceClass) (*servicecatalog.ClusterServiceClass, error)
Update(*servicecatalog.ClusterServiceClass) (*servicecatalog.ClusterServiceClass, error)
UpdateStatus(*servicecatalog.ClusterServiceClass) (*servicecatalog.ClusterServiceClass, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ClusterServiceClass, error)
List(opts v1.ListOptions) (*servicecatalog.ClusterServiceClassList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ClusterServiceClass, err error)
ClusterServiceClassExpansion
}
ClusterServiceClassInterface has methods to work with ClusterServiceClass resources.
type ClusterServiceClassesGetter ¶ added in v0.0.24
type ClusterServiceClassesGetter interface {
ClusterServiceClasses() ClusterServiceClassInterface
}
ClusterServiceClassesGetter has a method to return a ClusterServiceClassInterface. A group's client should implement this interface.
type ClusterServicePlanExpansion ¶ added in v0.0.24
type ClusterServicePlanExpansion interface{}
type ClusterServicePlanInterface ¶ added in v0.0.24
type ClusterServicePlanInterface interface {
Create(*servicecatalog.ClusterServicePlan) (*servicecatalog.ClusterServicePlan, error)
Update(*servicecatalog.ClusterServicePlan) (*servicecatalog.ClusterServicePlan, error)
UpdateStatus(*servicecatalog.ClusterServicePlan) (*servicecatalog.ClusterServicePlan, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ClusterServicePlan, error)
List(opts v1.ListOptions) (*servicecatalog.ClusterServicePlanList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ClusterServicePlan, err error)
ClusterServicePlanExpansion
}
ClusterServicePlanInterface has methods to work with ClusterServicePlan resources.
type ClusterServicePlansGetter ¶ added in v0.0.24
type ClusterServicePlansGetter interface {
ClusterServicePlans() ClusterServicePlanInterface
}
ClusterServicePlansGetter has a method to return a ClusterServicePlanInterface. A group's client should implement this interface.
type ServiceBindingExpansion ¶ added in v0.0.24
type ServiceBindingExpansion interface{}
type ServiceBindingInterface ¶ added in v0.0.24
type ServiceBindingInterface interface {
Create(*servicecatalog.ServiceBinding) (*servicecatalog.ServiceBinding, error)
Update(*servicecatalog.ServiceBinding) (*servicecatalog.ServiceBinding, error)
UpdateStatus(*servicecatalog.ServiceBinding) (*servicecatalog.ServiceBinding, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ServiceBinding, error)
List(opts v1.ListOptions) (*servicecatalog.ServiceBindingList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ServiceBinding, err error)
ServiceBindingExpansion
}
ServiceBindingInterface has methods to work with ServiceBinding resources.
type ServiceBindingsGetter ¶ added in v0.0.24
type ServiceBindingsGetter interface {
ServiceBindings(namespace string) ServiceBindingInterface
}
ServiceBindingsGetter has a method to return a ServiceBindingInterface. A group's client should implement this interface.
type ServiceBrokerExpansion ¶ added in v0.0.17
type ServiceBrokerExpansion interface{}
type ServiceBrokerInterface ¶ added in v0.0.17
type ServiceBrokerInterface interface {
Create(*servicecatalog.ServiceBroker) (*servicecatalog.ServiceBroker, error)
Update(*servicecatalog.ServiceBroker) (*servicecatalog.ServiceBroker, error)
UpdateStatus(*servicecatalog.ServiceBroker) (*servicecatalog.ServiceBroker, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ServiceBroker, error)
List(opts v1.ListOptions) (*servicecatalog.ServiceBrokerList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ServiceBroker, err error)
ServiceBrokerExpansion
}
ServiceBrokerInterface has methods to work with ServiceBroker resources.
type ServiceBrokersGetter ¶ added in v0.0.17
type ServiceBrokersGetter interface {
ServiceBrokers(namespace string) ServiceBrokerInterface
}
ServiceBrokersGetter has a method to return a ServiceBrokerInterface. A group's client should implement this interface.
type ServiceClassExpansion ¶
type ServiceClassExpansion interface{}
type ServiceClassInterface ¶
type ServiceClassInterface interface {
Create(*servicecatalog.ServiceClass) (*servicecatalog.ServiceClass, error)
Update(*servicecatalog.ServiceClass) (*servicecatalog.ServiceClass, error)
UpdateStatus(*servicecatalog.ServiceClass) (*servicecatalog.ServiceClass, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ServiceClass, error)
List(opts v1.ListOptions) (*servicecatalog.ServiceClassList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ServiceClass, err error)
ServiceClassExpansion
}
ServiceClassInterface has methods to work with ServiceClass resources.
type ServiceClassesGetter ¶
type ServiceClassesGetter interface {
ServiceClasses(namespace string) ServiceClassInterface
}
ServiceClassesGetter has a method to return a ServiceClassInterface. A group's client should implement this interface.
type ServiceInstanceExpansion ¶ added in v0.0.17
type ServiceInstanceExpansion interface{}
type ServiceInstanceInterface ¶ added in v0.0.17
type ServiceInstanceInterface interface {
Create(*servicecatalog.ServiceInstance) (*servicecatalog.ServiceInstance, error)
Update(*servicecatalog.ServiceInstance) (*servicecatalog.ServiceInstance, error)
UpdateStatus(*servicecatalog.ServiceInstance) (*servicecatalog.ServiceInstance, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ServiceInstance, error)
List(opts v1.ListOptions) (*servicecatalog.ServiceInstanceList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ServiceInstance, err error)
ServiceInstanceExpansion
}
ServiceInstanceInterface has methods to work with ServiceInstance resources.
type ServiceInstancesGetter ¶ added in v0.0.17
type ServiceInstancesGetter interface {
ServiceInstances(namespace string) ServiceInstanceInterface
}
ServiceInstancesGetter has a method to return a ServiceInstanceInterface. A group's client should implement this interface.
type ServicePlanExpansion ¶ added in v0.0.22
type ServicePlanExpansion interface{}
type ServicePlanInterface ¶ added in v0.0.22
type ServicePlanInterface interface {
Create(*servicecatalog.ServicePlan) (*servicecatalog.ServicePlan, error)
Update(*servicecatalog.ServicePlan) (*servicecatalog.ServicePlan, error)
UpdateStatus(*servicecatalog.ServicePlan) (*servicecatalog.ServicePlan, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*servicecatalog.ServicePlan, error)
List(opts v1.ListOptions) (*servicecatalog.ServicePlanList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *servicecatalog.ServicePlan, err error)
ServicePlanExpansion
}
ServicePlanInterface has methods to work with ServicePlan resources.
type ServicePlansGetter ¶ added in v0.0.22
type ServicePlansGetter interface {
ServicePlans(namespace string) ServicePlanInterface
}
ServicePlansGetter has a method to return a ServicePlanInterface. A group's client should implement this interface.
type ServicecatalogClient ¶
type ServicecatalogClient struct {
// contains filtered or unexported fields
}
ServicecatalogClient is used to interact with features provided by the servicecatalog.k8s.io group.
func New ¶
func New(c rest.Interface) *ServicecatalogClient
New creates a new ServicecatalogClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*ServicecatalogClient, error)
NewForConfig creates a new ServicecatalogClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *ServicecatalogClient
NewForConfigOrDie creates a new ServicecatalogClient for the given config and panics if there is an error in the config.
func (*ServicecatalogClient) ClusterServiceBrokers ¶ added in v0.0.24
func (c *ServicecatalogClient) ClusterServiceBrokers() ClusterServiceBrokerInterface
func (*ServicecatalogClient) ClusterServiceClasses ¶ added in v0.0.24
func (c *ServicecatalogClient) ClusterServiceClasses() ClusterServiceClassInterface
func (*ServicecatalogClient) ClusterServicePlans ¶ added in v0.0.24
func (c *ServicecatalogClient) ClusterServicePlans() ClusterServicePlanInterface
func (*ServicecatalogClient) RESTClient ¶
func (c *ServicecatalogClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*ServicecatalogClient) ServiceBindings ¶ added in v0.0.24
func (c *ServicecatalogClient) ServiceBindings(namespace string) ServiceBindingInterface
func (*ServicecatalogClient) ServiceBrokers ¶ added in v0.0.17
func (c *ServicecatalogClient) ServiceBrokers(namespace string) ServiceBrokerInterface
func (*ServicecatalogClient) ServiceClasses ¶
func (c *ServicecatalogClient) ServiceClasses(namespace string) ServiceClassInterface
func (*ServicecatalogClient) ServiceInstances ¶ added in v0.0.17
func (c *ServicecatalogClient) ServiceInstances(namespace string) ServiceInstanceInterface
func (*ServicecatalogClient) ServicePlans ¶ added in v0.0.22
func (c *ServicecatalogClient) ServicePlans(namespace string) ServicePlanInterface
type ServicecatalogInterface ¶
type ServicecatalogInterface interface {
RESTClient() rest.Interface
ClusterServiceBrokersGetter
ClusterServiceClassesGetter
ClusterServicePlansGetter
ServiceBindingsGetter
ServiceBrokersGetter
ServiceClassesGetter
ServiceInstancesGetter
ServicePlansGetter
}