Documentation
¶
Index ¶
- func NewClusterServiceBrokerInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterServiceClassInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterServicePlanInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterServiceBrokerInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterServiceClassInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterServicePlanInformer(client internalclientset.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServiceBindingInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewFilteredServiceBrokerInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewFilteredServiceClassInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewFilteredServiceInstanceInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewFilteredServicePlanInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewServiceBindingInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewServiceBrokerInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewServiceClassInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewServiceInstanceInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- func NewServicePlanInformer(client internalclientset.Interface, namespace string, ...) cache.SharedIndexInformer
- type ClusterServiceBrokerInformer
- type ClusterServiceClassInformer
- type ClusterServicePlanInformer
- type Interface
- type ServiceBindingInformer
- type ServiceBrokerInformer
- type ServiceClassInformer
- type ServiceInstanceInformer
- type ServicePlanInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterServiceBrokerInformer ¶ added in v0.0.24
func NewClusterServiceBrokerInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterServiceBrokerInformer constructs a new informer for ClusterServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterServiceClassInformer ¶ added in v0.0.24
func NewClusterServiceClassInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterServiceClassInformer constructs a new informer for ClusterServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterServicePlanInformer ¶ added in v0.0.24
func NewClusterServicePlanInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterServicePlanInformer constructs a new informer for ClusterServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterServiceBrokerInformer ¶ added in v0.1.31
func NewFilteredClusterServiceBrokerInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterServiceBrokerInformer constructs a new informer for ClusterServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterServiceClassInformer ¶ added in v0.1.31
func NewFilteredClusterServiceClassInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterServiceClassInformer constructs a new informer for ClusterServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterServicePlanInformer ¶ added in v0.1.31
func NewFilteredClusterServicePlanInformer(client internalclientset.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterServicePlanInformer constructs a new informer for ClusterServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceBindingInformer ¶ added in v0.1.31
func NewFilteredServiceBindingInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceBindingInformer constructs a new informer for ServiceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceBrokerInformer ¶ added in v0.1.31
func NewFilteredServiceBrokerInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceBrokerInformer constructs a new informer for ServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceClassInformer ¶ added in v0.1.31
func NewFilteredServiceClassInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceClassInformer constructs a new informer for ServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceInstanceInformer ¶ added in v0.1.31
func NewFilteredServiceInstanceInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceInstanceInformer constructs a new informer for ServiceInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServicePlanInformer ¶ added in v0.1.31
func NewFilteredServicePlanInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServicePlanInformer constructs a new informer for ServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceBindingInformer ¶ added in v0.0.24
func NewServiceBindingInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceBindingInformer constructs a new informer for ServiceBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceBrokerInformer ¶ added in v0.1.31
func NewServiceBrokerInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceBrokerInformer constructs a new informer for ServiceBroker type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceClassInformer ¶ added in v0.1.31
func NewServiceClassInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceClassInformer constructs a new informer for ServiceClass type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceInstanceInformer ¶ added in v0.0.24
func NewServiceInstanceInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceInstanceInformer constructs a new informer for ServiceInstance type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServicePlanInformer ¶ added in v0.1.31
func NewServicePlanInformer(client internalclientset.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServicePlanInformer constructs a new informer for ServicePlan type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ClusterServiceBrokerInformer ¶ added in v0.0.24
type ClusterServiceBrokerInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ClusterServiceBrokerLister
}
ClusterServiceBrokerInformer provides access to a shared informer and lister for ClusterServiceBrokers.
type ClusterServiceClassInformer ¶ added in v0.0.24
type ClusterServiceClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ClusterServiceClassLister
}
ClusterServiceClassInformer provides access to a shared informer and lister for ClusterServiceClasses.
type ClusterServicePlanInformer ¶ added in v0.0.24
type ClusterServicePlanInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ClusterServicePlanLister
}
ClusterServicePlanInformer provides access to a shared informer and lister for ClusterServicePlans.
type Interface ¶
type Interface interface {
// ClusterServiceBrokers returns a ClusterServiceBrokerInformer.
ClusterServiceBrokers() ClusterServiceBrokerInformer
// ClusterServiceClasses returns a ClusterServiceClassInformer.
ClusterServiceClasses() ClusterServiceClassInformer
// ClusterServicePlans returns a ClusterServicePlanInformer.
ClusterServicePlans() ClusterServicePlanInformer
// ServiceBindings returns a ServiceBindingInformer.
ServiceBindings() ServiceBindingInformer
// ServiceBrokers returns a ServiceBrokerInformer.
ServiceBrokers() ServiceBrokerInformer
// ServiceClasses returns a ServiceClassInformer.
ServiceClasses() ServiceClassInformer
// ServiceInstances returns a ServiceInstanceInformer.
ServiceInstances() ServiceInstanceInformer
// ServicePlans returns a ServicePlanInformer.
ServicePlans() ServicePlanInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type ServiceBindingInformer ¶ added in v0.0.24
type ServiceBindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ServiceBindingLister
}
ServiceBindingInformer provides access to a shared informer and lister for ServiceBindings.
type ServiceBrokerInformer ¶ added in v0.0.17
type ServiceBrokerInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ServiceBrokerLister
}
ServiceBrokerInformer provides access to a shared informer and lister for ServiceBrokers.
type ServiceClassInformer ¶
type ServiceClassInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ServiceClassLister
}
ServiceClassInformer provides access to a shared informer and lister for ServiceClasses.
type ServiceInstanceInformer ¶ added in v0.0.17
type ServiceInstanceInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ServiceInstanceLister
}
ServiceInstanceInformer provides access to a shared informer and lister for ServiceInstances.
type ServicePlanInformer ¶ added in v0.0.22
type ServicePlanInformer interface {
Informer() cache.SharedIndexInformer
Lister() internalversion.ServicePlanLister
}
ServicePlanInformer provides access to a shared informer and lister for ServicePlans.