Documentation
¶
Index ¶
- type ClusterServiceBrokerLister
- type ClusterServiceBrokerListerExpansion
- type ClusterServiceClassLister
- type ClusterServiceClassListerExpansion
- type ClusterServicePlanLister
- type ClusterServicePlanListerExpansion
- type ServiceBindingLister
- type ServiceBindingListerExpansion
- type ServiceBindingNamespaceLister
- type ServiceBindingNamespaceListerExpansion
- type ServiceBrokerLister
- type ServiceBrokerListerExpansion
- type ServiceBrokerNamespaceLister
- type ServiceBrokerNamespaceListerExpansion
- type ServiceClassLister
- type ServiceClassListerExpansion
- type ServiceClassNamespaceLister
- type ServiceClassNamespaceListerExpansion
- type ServiceInstanceLister
- type ServiceInstanceListerExpansion
- type ServiceInstanceNamespaceLister
- type ServiceInstanceNamespaceListerExpansion
- type ServicePlanLister
- type ServicePlanListerExpansion
- type ServicePlanNamespaceLister
- type ServicePlanNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterServiceBrokerLister ¶
type ClusterServiceBrokerLister interface {
// List lists all ClusterServiceBrokers in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ClusterServiceBroker, err error)
// Get retrieves the ClusterServiceBroker from the index for a given name.
Get(name string) (*v1beta1.ClusterServiceBroker, error)
ClusterServiceBrokerListerExpansion
}
ClusterServiceBrokerLister helps list ClusterServiceBrokers.
func NewClusterServiceBrokerLister ¶
func NewClusterServiceBrokerLister(indexer cache.Indexer) ClusterServiceBrokerLister
NewClusterServiceBrokerLister returns a new ClusterServiceBrokerLister.
type ClusterServiceBrokerListerExpansion ¶
type ClusterServiceBrokerListerExpansion interface{}
ClusterServiceBrokerListerExpansion allows custom methods to be added to ClusterServiceBrokerLister.
type ClusterServiceClassLister ¶
type ClusterServiceClassLister interface {
// List lists all ClusterServiceClasses in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ClusterServiceClass, err error)
// Get retrieves the ClusterServiceClass from the index for a given name.
Get(name string) (*v1beta1.ClusterServiceClass, error)
ClusterServiceClassListerExpansion
}
ClusterServiceClassLister helps list ClusterServiceClasses.
func NewClusterServiceClassLister ¶
func NewClusterServiceClassLister(indexer cache.Indexer) ClusterServiceClassLister
NewClusterServiceClassLister returns a new ClusterServiceClassLister.
type ClusterServiceClassListerExpansion ¶
type ClusterServiceClassListerExpansion interface{}
ClusterServiceClassListerExpansion allows custom methods to be added to ClusterServiceClassLister.
type ClusterServicePlanLister ¶
type ClusterServicePlanLister interface {
// List lists all ClusterServicePlans in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ClusterServicePlan, err error)
// Get retrieves the ClusterServicePlan from the index for a given name.
Get(name string) (*v1beta1.ClusterServicePlan, error)
ClusterServicePlanListerExpansion
}
ClusterServicePlanLister helps list ClusterServicePlans.
func NewClusterServicePlanLister ¶
func NewClusterServicePlanLister(indexer cache.Indexer) ClusterServicePlanLister
NewClusterServicePlanLister returns a new ClusterServicePlanLister.
type ClusterServicePlanListerExpansion ¶
type ClusterServicePlanListerExpansion interface{}
ClusterServicePlanListerExpansion allows custom methods to be added to ClusterServicePlanLister.
type ServiceBindingLister ¶
type ServiceBindingLister interface {
// List lists all ServiceBindings in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ServiceBinding, err error)
// ServiceBindings returns an object that can list and get ServiceBindings.
ServiceBindings(namespace string) ServiceBindingNamespaceLister
ServiceBindingListerExpansion
}
ServiceBindingLister helps list ServiceBindings.
func NewServiceBindingLister ¶
func NewServiceBindingLister(indexer cache.Indexer) ServiceBindingLister
NewServiceBindingLister returns a new ServiceBindingLister.
type ServiceBindingListerExpansion ¶
type ServiceBindingListerExpansion interface{}
ServiceBindingListerExpansion allows custom methods to be added to ServiceBindingLister.
type ServiceBindingNamespaceLister ¶
type ServiceBindingNamespaceLister interface {
// List lists all ServiceBindings in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.ServiceBinding, err error)
// Get retrieves the ServiceBinding from the indexer for a given namespace and name.
Get(name string) (*v1beta1.ServiceBinding, error)
ServiceBindingNamespaceListerExpansion
}
ServiceBindingNamespaceLister helps list and get ServiceBindings.
type ServiceBindingNamespaceListerExpansion ¶
type ServiceBindingNamespaceListerExpansion interface{}
ServiceBindingNamespaceListerExpansion allows custom methods to be added to ServiceBindingNamespaceLister.
type ServiceBrokerLister ¶ added in v0.1.31
type ServiceBrokerLister interface {
// List lists all ServiceBrokers in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ServiceBroker, err error)
// ServiceBrokers returns an object that can list and get ServiceBrokers.
ServiceBrokers(namespace string) ServiceBrokerNamespaceLister
ServiceBrokerListerExpansion
}
ServiceBrokerLister helps list ServiceBrokers.
func NewServiceBrokerLister ¶ added in v0.1.31
func NewServiceBrokerLister(indexer cache.Indexer) ServiceBrokerLister
NewServiceBrokerLister returns a new ServiceBrokerLister.
type ServiceBrokerListerExpansion ¶ added in v0.1.31
type ServiceBrokerListerExpansion interface{}
ServiceBrokerListerExpansion allows custom methods to be added to ServiceBrokerLister.
type ServiceBrokerNamespaceLister ¶ added in v0.1.31
type ServiceBrokerNamespaceLister interface {
// List lists all ServiceBrokers in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.ServiceBroker, err error)
// Get retrieves the ServiceBroker from the indexer for a given namespace and name.
Get(name string) (*v1beta1.ServiceBroker, error)
ServiceBrokerNamespaceListerExpansion
}
ServiceBrokerNamespaceLister helps list and get ServiceBrokers.
type ServiceBrokerNamespaceListerExpansion ¶ added in v0.1.31
type ServiceBrokerNamespaceListerExpansion interface{}
ServiceBrokerNamespaceListerExpansion allows custom methods to be added to ServiceBrokerNamespaceLister.
type ServiceClassLister ¶ added in v0.1.31
type ServiceClassLister interface {
// List lists all ServiceClasses in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ServiceClass, err error)
// ServiceClasses returns an object that can list and get ServiceClasses.
ServiceClasses(namespace string) ServiceClassNamespaceLister
ServiceClassListerExpansion
}
ServiceClassLister helps list ServiceClasses.
func NewServiceClassLister ¶ added in v0.1.31
func NewServiceClassLister(indexer cache.Indexer) ServiceClassLister
NewServiceClassLister returns a new ServiceClassLister.
type ServiceClassListerExpansion ¶ added in v0.1.31
type ServiceClassListerExpansion interface{}
ServiceClassListerExpansion allows custom methods to be added to ServiceClassLister.
type ServiceClassNamespaceLister ¶ added in v0.1.31
type ServiceClassNamespaceLister interface {
// List lists all ServiceClasses in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.ServiceClass, err error)
// Get retrieves the ServiceClass from the indexer for a given namespace and name.
Get(name string) (*v1beta1.ServiceClass, error)
ServiceClassNamespaceListerExpansion
}
ServiceClassNamespaceLister helps list and get ServiceClasses.
type ServiceClassNamespaceListerExpansion ¶ added in v0.1.31
type ServiceClassNamespaceListerExpansion interface{}
ServiceClassNamespaceListerExpansion allows custom methods to be added to ServiceClassNamespaceLister.
type ServiceInstanceLister ¶
type ServiceInstanceLister interface {
// List lists all ServiceInstances in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ServiceInstance, err error)
// ServiceInstances returns an object that can list and get ServiceInstances.
ServiceInstances(namespace string) ServiceInstanceNamespaceLister
ServiceInstanceListerExpansion
}
ServiceInstanceLister helps list ServiceInstances.
func NewServiceInstanceLister ¶
func NewServiceInstanceLister(indexer cache.Indexer) ServiceInstanceLister
NewServiceInstanceLister returns a new ServiceInstanceLister.
type ServiceInstanceListerExpansion ¶
type ServiceInstanceListerExpansion interface{}
ServiceInstanceListerExpansion allows custom methods to be added to ServiceInstanceLister.
type ServiceInstanceNamespaceLister ¶
type ServiceInstanceNamespaceLister interface {
// List lists all ServiceInstances in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.ServiceInstance, err error)
// Get retrieves the ServiceInstance from the indexer for a given namespace and name.
Get(name string) (*v1beta1.ServiceInstance, error)
ServiceInstanceNamespaceListerExpansion
}
ServiceInstanceNamespaceLister helps list and get ServiceInstances.
type ServiceInstanceNamespaceListerExpansion ¶
type ServiceInstanceNamespaceListerExpansion interface{}
ServiceInstanceNamespaceListerExpansion allows custom methods to be added to ServiceInstanceNamespaceLister.
type ServicePlanLister ¶ added in v0.1.31
type ServicePlanLister interface {
// List lists all ServicePlans in the indexer.
List(selector labels.Selector) (ret []*v1beta1.ServicePlan, err error)
// ServicePlans returns an object that can list and get ServicePlans.
ServicePlans(namespace string) ServicePlanNamespaceLister
ServicePlanListerExpansion
}
ServicePlanLister helps list ServicePlans.
func NewServicePlanLister ¶ added in v0.1.31
func NewServicePlanLister(indexer cache.Indexer) ServicePlanLister
NewServicePlanLister returns a new ServicePlanLister.
type ServicePlanListerExpansion ¶ added in v0.1.31
type ServicePlanListerExpansion interface{}
ServicePlanListerExpansion allows custom methods to be added to ServicePlanLister.
type ServicePlanNamespaceLister ¶ added in v0.1.31
type ServicePlanNamespaceLister interface {
// List lists all ServicePlans in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.ServicePlan, err error)
// Get retrieves the ServicePlan from the indexer for a given namespace and name.
Get(name string) (*v1beta1.ServicePlan, error)
ServicePlanNamespaceListerExpansion
}
ServicePlanNamespaceLister helps list and get ServicePlans.
type ServicePlanNamespaceListerExpansion ¶ added in v0.1.31
type ServicePlanNamespaceListerExpansion interface{}
ServicePlanNamespaceListerExpansion allows custom methods to be added to ServicePlanNamespaceLister.